@@ -8,7 +8,10 @@ pub use self::data::{
 use super::InteractionType;
 use crate::{
     guild::PartialMember,
-    id::{ApplicationId, ChannelId, GuildId, InteractionId},
+    id::{
+        marker::{ApplicationMarker, ChannelMarker, GuildMarker, InteractionMarker},
+        Id,
+    },
     user::User,
 };
 use serde::Serialize;
@@ -21,14 +24,14 @@ use serde::Serialize;
 #[serde(rename(serialize = "Interaction"))]
 pub struct ApplicationCommand {
     /// ID of the associated application.
-    pub application_id: ApplicationId,
+    pub application_id: Id<ApplicationMarker>,
     /// The channel the interaction was triggered from.
-    pub channel_id: ChannelId,
+    pub channel_id: Id<ChannelMarker>,
     /// Data from the invoked command.
     pub data: CommandData,
     /// ID of the guild the interaction was triggered from.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub guild_id: Option<GuildId>,
+    pub guild_id: Option<Id<GuildMarker>>,
     /// Guild's preferred locale.
     ///
     /// Present when the command is used in a guild.
@@ -37,7 +40,7 @@ pub struct ApplicationCommand {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub guild_locale: Option<String>,
     /// ID of the interaction.
-    pub id: InteractionId,
+    pub id: Id<InteractionMarker>,
     /// Kind of the interaction.
     #[serde(rename = "type")]
     pub kind: InteractionType,
