@@ -6,7 +6,10 @@ use super::InteractionType;
 use crate::{
     channel::Message,
     guild::PartialMember,
-    id::{ApplicationId, ChannelId, GuildId, InteractionId, UserId},
+    id::{
+        marker::{ApplicationMarker, ChannelMarker, GuildMarker, InteractionMarker, UserMarker},
+        Id,
+    },
     user::User,
 };
 use serde::Serialize;
@@ -18,13 +21,13 @@ use serde::Serialize;
 #[serde(rename(serialize = "Interaction"))]
 pub struct MessageComponentInteraction {
     /// ID of the associated application.
-    pub application_id: ApplicationId,
+    pub application_id: Id<ApplicationMarker>,
     /// ID of the channel the interaction was triggered from.
-    pub channel_id: ChannelId,
+    pub channel_id: Id<ChannelMarker>,
     /// Data from the invoked command.
     pub data: MessageComponentInteractionData,
     /// ID of the guild the interaction was triggered from.
-    pub guild_id: Option<GuildId>,
+    pub guild_id: Option<Id<GuildMarker>>,
     /// Guild's preferred locale.
     ///
     /// Present when the command is used in a guild.
@@ -33,7 +36,7 @@ pub struct MessageComponentInteraction {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub guild_locale: Option<String>,
     /// ID of the interaction.
-    pub id: InteractionId,
+    pub id: Id<InteractionMarker>,
     /// Type of the interaction.
     #[serde(rename = "type")]
     pub kind: InteractionType,
@@ -67,7 +70,7 @@ impl MessageComponentInteraction {
     ///
     /// [`member`]: Self::member
     /// [`user`]: Self::user
-    pub const fn author_id(&self) -> Option<UserId> {
+    pub const fn author_id(&self) -> Option<Id<UserMarker>> {
         if let Some(member) = &self.member {
             if let Some(user) = &member.user {
                 return Some(user.id);
@@ -90,7 +93,7 @@ mod tests {
         channel::message::{Message, MessageType},
         datetime::{Timestamp, TimestampParseError},
         guild::PartialMember,
-        id::{ApplicationId, ChannelId, GuildId, InteractionId, MessageId, UserId},
+        id::{marker::UserMarker, Id},
         user::User,
     };
     use serde::Serialize;
@@ -120,7 +123,7 @@ mod tests {
         Sync
     );
 
-    fn user(id: UserId) -> User {
+    fn user(id: Id<UserMarker>) -> User {
         User {
             accent_color: None,
             avatar: None,
@@ -142,23 +145,21 @@ mod tests {
 
     #[test]
     fn test_author_id() -> Result<(), TimestampParseError> {
-        fn user_id() -> UserId {
-            UserId::new(7).expect("non zero")
-        }
+        const USER_ID: Id<UserMarker> = Id::new(7);
 
         let timestamp = Timestamp::from_str("2020-02-02T02:02:02.020000+00:00")?;
 
         let in_guild = MessageComponentInteraction {
-            application_id: ApplicationId::new(1).expect("non zero"),
-            channel_id: ChannelId::new(2).expect("non zero"),
+            application_id: Id::new(1),
+            channel_id: Id::new(2),
             data: MessageComponentInteractionData {
                 custom_id: "foo".to_owned(),
                 component_type: ComponentType::Button,
                 values: Vec::from(["bar".to_owned()]),
             },
-            guild_id: Some(GuildId::new(3).expect("non zero")),
+            guild_id: Some(Id::new(3)),
             guild_locale: None,
-            id: InteractionId::new(4).expect("non zero"),
+            id: Id::new(4),
             kind: InteractionType::MessageComponent,
             locale: "en-GB".to_owned(),
             member: Some(PartialMember {
@@ -171,22 +172,22 @@ mod tests {
                 permissions: None,
                 premium_since: None,
                 roles: Vec::new(),
-                user: Some(user(user_id())),
+                user: Some(user(USER_ID)),
             }),
             message: Message {
                 activity: None,
                 application: None,
                 application_id: None,
                 attachments: Vec::new(),
-                author: user(user_id()),
-                channel_id: ChannelId::new(5).expect("non zero"),
+                author: user(USER_ID),
+                channel_id: Id::new(5),
                 components: Vec::new(),
                 content: String::new(),
                 edited_timestamp: None,
                 embeds: Vec::new(),
                 flags: None,
-                guild_id: Some(GuildId::new(3).expect("non zero")),
-                id: MessageId::new(6).expect("non zero"),
+                guild_id: Some(Id::new(3)),
+                id: Id::new(6),
                 interaction: None,
                 kind: MessageType::Regular,
                 member: None,
@@ -208,7 +209,7 @@ mod tests {
             user: None,
         };
 
-        assert_eq!(Some(user_id()), in_guild.author_id());
+        assert_eq!(Some(USER_ID), in_guild.author_id());
 
         let in_dm = MessageComponentInteraction {
             member: None,
@@ -216,10 +217,10 @@ mod tests {
                 guild_id: None,
                 ..in_guild.message
             },
-            user: Some(user(user_id())),
+            user: Some(user(USER_ID)),
             ..in_guild
         };
-        assert_eq!(Some(user_id()), in_dm.author_id());
+        assert_eq!(Some(USER_ID), in_dm.author_id());
 
         Ok(())
     }
