@@ -14,7 +14,10 @@ pub use self::{
 use crate::{
     channel::Message,
     guild::PartialMember,
-    id::{ApplicationId, ChannelId, GuildId, InteractionId},
+    id::{
+        marker::{ApplicationMarker, ChannelMarker, GuildMarker, InteractionMarker},
+        Id,
+    },
     user::User,
 };
 use serde::{
@@ -45,7 +48,7 @@ pub enum Interaction {
 }
 
 impl Interaction {
-    pub const fn guild_id(&self) -> Option<GuildId> {
+    pub const fn guild_id(&self) -> Option<Id<GuildMarker>> {
         match self {
             Self::Ping(_) => None,
             Self::ApplicationCommand(inner) | Self::ApplicationCommandAutocomplete(inner) => {
@@ -56,7 +59,7 @@ impl Interaction {
     }
 
     /// Return the ID of the inner interaction.
-    pub const fn id(&self) -> InteractionId {
+    pub const fn id(&self) -> Id<InteractionMarker> {
         match self {
             Self::Ping(ping) => ping.id,
             Self::ApplicationCommand(command) | Self::ApplicationCommandAutocomplete(command) => {
@@ -101,12 +104,12 @@ impl<'de> Visitor<'de> for InteractionVisitor {
 
     #[allow(clippy::too_many_lines)]
     fn visit_map<V: MapAccess<'de>>(self, mut map: V) -> Result<Self::Value, V::Error> {
-        let mut application_id: Option<ApplicationId> = None;
-        let mut channel_id: Option<ChannelId> = None;
+        let mut application_id: Option<Id<ApplicationMarker>> = None;
+        let mut channel_id: Option<Id<ChannelMarker>> = None;
         let mut data: Option<Value> = None;
-        let mut guild_id: Option<Option<GuildId>> = None;
+        let mut guild_id: Option<Option<Id<GuildMarker>>> = None;
         let mut guild_locale: Option<Option<String>> = None;
-        let mut id: Option<InteractionId> = None;
+        let mut id: Option<Id<InteractionMarker>> = None;
         let mut member: Option<Option<PartialMember>> = None;
         let mut message: Option<Message> = None;
         let mut token: Option<String> = None;
@@ -355,7 +358,8 @@ mod test {
         },
         datetime::{Timestamp, TimestampParseError},
         guild::{PartialMember, Permissions},
-        id::{ApplicationId, ChannelId, CommandId, GuildId, InteractionId, UserId},
+        id::Id,
+        test::image_hash,
         user::User,
     };
     use serde_test::Token;
@@ -367,20 +371,20 @@ mod test {
         let joined_at = Timestamp::from_str("2020-01-01T00:00:00.000000+00:00")?;
 
         let value = Interaction::ApplicationCommand(Box::new(ApplicationCommand {
-            application_id: ApplicationId::new(100).expect("non zero"),
-            channel_id: ChannelId::new(200).expect("non zero"),
+            application_id: Id::new(100),
+            channel_id: Id::new(200),
             data: CommandData {
-                id: CommandId::new(300).expect("non zero"),
+                id: Id::new(300),
                 name: "command name".into(),
                 options: Vec::from([CommandDataOption {
                     focused: false,
                     name: "member".into(),
-                    value: CommandOptionValue::User(UserId::new(600).expect("non zero")),
+                    value: CommandOptionValue::User(Id::new(600)),
                 }]),
                 resolved: Some(CommandInteractionDataResolved {
                     channels: HashMap::new(),
                     members: IntoIterator::into_iter([(
-                        UserId::new(600).expect("non zero"),
+                        Id::new(600),
                         InteractionMember {
                             avatar: None,
                             communication_disabled_until: None,
@@ -396,16 +400,16 @@ mod test {
                     messages: HashMap::new(),
                     roles: HashMap::new(),
                     users: IntoIterator::into_iter([(
-                        UserId::new(600).expect("non zero"),
+                        Id::new(600),
                         User {
                             accent_color: None,
-                            avatar: Some("avatar string".into()),
+                            avatar: Some(image_hash::AVATAR),
                             banner: None,
                             bot: false,
                             discriminator: 1111,
                             email: None,
                             flags: None,
-                            id: UserId::new(600).expect("non zero"),
+                            id: Id::new(600),
                             locale: None,
                             mfa_enabled: None,
                             name: "username".into(),
@@ -418,9 +422,9 @@ mod test {
                     .collect(),
                 }),
             },
-            guild_id: Some(GuildId::new(400).expect("non zero")),
+            guild_id: Some(Id::new(400)),
             guild_locale: Some("de".to_owned()),
-            id: InteractionId::new(500).expect("non zero"),
+            id: Id::new(500),
             kind: InteractionType::ApplicationCommand,
             locale: "en-GB".to_owned(),
             member: Some(PartialMember {
@@ -435,13 +439,13 @@ mod test {
                 roles: Vec::new(),
                 user: Some(User {
                     accent_color: None,
-                    avatar: Some("avatar string".into()),
+                    avatar: Some(image_hash::AVATAR),
                     banner: None,
                     bot: false,
                     discriminator: 1111,
                     email: None,
                     flags: None,
-                    id: UserId::new(600).expect("non zero"),
+                    id: Id::new(600),
                     locale: None,
                     mfa_enabled: None,
                     name: "username".into(),
@@ -463,12 +467,10 @@ mod test {
                     len: 10,
                 },
                 Token::Str("application_id"),
-                Token::NewtypeStruct {
-                    name: "ApplicationId",
-                },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("100"),
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("200"),
                 Token::Str("data"),
                 Token::Struct {
@@ -476,7 +478,7 @@ mod test {
                     len: 4,
                 },
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "CommandId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("300"),
                 Token::Str("name"),
                 Token::Str("command name"),
@@ -491,7 +493,7 @@ mod test {
                 Token::Str("type"),
                 Token::U8(CommandOptionType::User as u8),
                 Token::Str("value"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("600"),
                 Token::StructEnd,
                 Token::SeqEnd,
@@ -503,7 +505,7 @@ mod test {
                 },
                 Token::Str("members"),
                 Token::Map { len: Some(1) },
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("600"),
                 Token::Struct {
                     name: "InteractionMember",
@@ -527,7 +529,7 @@ mod test {
                 Token::MapEnd,
                 Token::Str("users"),
                 Token::Map { len: Some(1) },
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("600"),
                 Token::Struct {
                     name: "User",
@@ -537,7 +539,7 @@ mod test {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("avatar string"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -545,7 +547,7 @@ mod test {
                 Token::Str("discriminator"),
                 Token::Str("1111"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("600"),
                 Token::Str("username"),
                 Token::Str("username"),
@@ -555,15 +557,13 @@ mod test {
                 Token::StructEnd,
                 Token::Str("guild_id"),
                 Token::Some,
-                Token::NewtypeStruct { name: "GuildId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("400"),
                 Token::Str("guild_locale"),
                 Token::Some,
                 Token::String("de"),
                 Token::Str("id"),
-                Token::NewtypeStruct {
-                    name: "InteractionId",
-                },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("500"),
                 Token::Str("type"),
                 Token::U8(2),
@@ -602,7 +602,7 @@ mod test {
                 Token::None,
                 Token::Str("avatar"),
                 Token::Some,
-                Token::Str("avatar string"),
+                Token::Str(image_hash::AVATAR_INPUT),
                 Token::Str("banner"),
                 Token::None,
                 Token::Str("bot"),
@@ -610,7 +610,7 @@ mod test {
                 Token::Str("discriminator"),
                 Token::Str("1111"),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("600"),
                 Token::Str("username"),
                 Token::Str("username"),
