@@ -1,9 +1,13 @@
-use crate::{application::interaction::InteractionType, id::InteractionId, user::User};
+use crate::{
+    application::interaction::InteractionType,
+    id::{marker::InteractionMarker, Id},
+    user::User,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct MessageInteraction {
-    pub id: InteractionId,
+    pub id: Id<InteractionMarker>,
     #[serde(rename = "type")]
     pub kind: InteractionType,
     pub name: String,
