@@ -1,6 +1,5 @@
 use serde_repr::{Deserialize_repr, Serialize_repr};
 use std::{
-    convert::TryFrom,
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
 };
@@ -63,7 +62,6 @@ impl Error for StickerTypeConversionError {}
 mod tests {
     use super::StickerType;
     use serde_test::Token;
-    use std::convert::TryFrom;
 
     #[test]
     fn test_variants() {
