@@ -9,7 +9,12 @@ use crate::{
         DefaultMessageNotificationLevel, ExplicitContentFilter, MfaLevel, NSFWLevel, Permissions,
         VerificationLevel,
     },
-    id::{ApplicationId, ChannelId, GenericId, GuildId, RoleId, UserId},
+    id::{
+        marker::{
+            ApplicationMarker, ChannelMarker, GenericMarker, GuildMarker, RoleMarker, UserMarker,
+        },
+        Id,
+    },
 };
 use serde::{Deserialize, Serialize};
 
@@ -24,7 +29,7 @@ use serde::{Deserialize, Serialize};
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct AffectedRole {
     /// ID of the role.
-    pub id: RoleId,
+    pub id: Id<RoleMarker>,
     /// Name of the role.
     pub name: String,
 }
@@ -40,10 +45,10 @@ pub enum AuditLogChange {
     AfkChannelId {
         /// New ID of the AFK channel.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old ID of the AFK channel.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Timeout to cause a user to be moved to an AFK voice channel.
     AfkTimeout {
@@ -67,9 +72,9 @@ pub enum AuditLogChange {
     ApplicationId {
         /// Application's ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ApplicationId>,
+        new: Option<Id<ApplicationMarker>>,
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ApplicationId>,
+        old: Option<Id<ApplicationMarker>>,
     },
     /// Thread is now archived/unarchived.
     Archived {
@@ -138,10 +143,10 @@ pub enum AuditLogChange {
     ChannelId {
         /// New invite's channel.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old invite's channel.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Code of an invite.
     Code {
@@ -282,10 +287,10 @@ pub enum AuditLogChange {
     GuildId {
         /// New guild that a sticker is in.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<GuildId>,
+        new: Option<Id<GuildMarker>>,
         /// Old guild that a sticker is in.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<GuildId>,
+        old: Option<Id<GuildMarker>>,
     },
     /// Whether a role is hoisted.
     Hoist {
@@ -309,9 +314,9 @@ pub enum AuditLogChange {
     Id {
         /// New entity's ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<GenericId>,
+        new: Option<Id<GenericMarker>>,
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<GenericId>,
+        old: Option<Id<GenericMarker>>,
     },
     /// Invitable state of a private thread.
     Invitable {
@@ -326,13 +331,13 @@ pub enum AuditLogChange {
     InviterId {
         /// User ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<UserId>,
+        new: Option<Id<UserMarker>>,
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<UserId>,
+        old: Option<Id<UserMarker>>,
     },
     /// Location for a scheduled event changed.
     ///
-    /// Can be a [`ChannelId`] or a [`String`].
+    /// Can be an [`Id<ChannelMarker>`] or a [`String`].
     Location {
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
         new: Option<String>,
@@ -433,10 +438,10 @@ pub enum AuditLogChange {
     OwnerId {
         /// New owner's ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<UserId>,
+        new: Option<Id<UserMarker>>,
         /// Old owner's ID.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<UserId>,
+        old: Option<Id<UserMarker>>,
     },
     /// Permission overwrites on a channel changed.
     PermissionOverwrites {
@@ -495,10 +500,10 @@ pub enum AuditLogChange {
     PublicUpdatesChannelId {
         /// New public updates channel ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old public updates channel ID.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Ratelimit per user in a textual channel.
     RateLimitPerUser {
@@ -542,10 +547,10 @@ pub enum AuditLogChange {
     RulesChannelId {
         /// New rules channel.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old rules channel.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Hash of a guild's splash.
     SplashHash {
@@ -569,10 +574,10 @@ pub enum AuditLogChange {
     SystemChannelId {
         /// New system channel ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old system channel ID.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Related emoji of a sticker.
     Tags {
@@ -659,10 +664,10 @@ pub enum AuditLogChange {
     WidgetChannelId {
         /// New channel ID.
         #[serde(rename = "new_value", skip_serializing_if = "Option::is_none")]
-        new: Option<ChannelId>,
+        new: Option<Id<ChannelMarker>>,
         /// Old channel ID.
         #[serde(rename = "old_value", skip_serializing_if = "Option::is_none")]
-        old: Option<ChannelId>,
+        old: Option<Id<ChannelMarker>>,
     },
     /// Whether a widget is enabled.
     WidgetEnabled {
@@ -790,7 +795,7 @@ impl AuditLogChange {
 #[cfg(test)]
 mod tests {
     use super::{super::AuditLogChangeKey, AffectedRole, AuditLogChange};
-    use crate::{guild::Permissions, id::ChannelId};
+    use crate::{guild::Permissions, id::Id};
     use serde::{Deserialize, Serialize};
     use serde_test::Token;
     use static_assertions::{assert_fields, assert_impl_all};
@@ -878,7 +883,7 @@ mod tests {
     #[test]
     fn test_afk_channel_id() {
         let value = AuditLogChange::AfkChannelId {
-            new: Some(ChannelId::new(1).expect("non zero")),
+            new: Some(Id::new(1)),
             old: None,
         };
 
@@ -895,7 +900,7 @@ mod tests {
                 Token::String("afk_channel_id"),
                 Token::String("new_value"),
                 Token::Some,
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::String("1"),
                 Token::StructEnd,
             ],
