@@ -1,21 +1,22 @@
-use crate::id::ChannelId;
+use crate::id::{marker::ChannelMarker, Id};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct GuildWidget {
-    pub channel_id: ChannelId,
+    pub channel_id: Option<Id<ChannelMarker>>,
     pub enabled: bool,
 }
 
 #[cfg(test)]
 mod tests {
-    use super::{ChannelId, GuildWidget};
+    use super::GuildWidget;
+    use crate::id::Id;
     use serde_test::Token;
 
     #[test]
     fn test_guild_widget() {
         let value = GuildWidget {
-            channel_id: ChannelId::new(111_111_111_111_111_111).expect("non zero"),
+            channel_id: Some(Id::new(111_111_111_111_111_111)),
             enabled: true,
         };
 
@@ -27,7 +28,8 @@ mod tests {
                     len: 2,
                 },
                 Token::Str("channel_id"),
-                Token::NewtypeStruct { name: "ChannelId" },
+                Token::Some,
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("111111111111111111"),
                 Token::Str("enabled"),
                 Token::Bool(true),
