@@ -3,21 +3,28 @@ mod membership_state;
 
 pub use self::{member::TeamMember, membership_state::TeamMembershipState};
 
-use crate::{id::UserId, oauth::id::TeamId};
+use crate::{
+    id::{
+        marker::{OauthTeamMarker, UserMarker},
+        Id,
+    },
+    util::image_hash::ImageHash,
+};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Eq, Hash, PartialEq, Serialize)]
 pub struct Team {
-    pub icon: Option<String>,
-    pub id: TeamId,
+    pub icon: Option<ImageHash>,
+    pub id: Id<OauthTeamMarker>,
     pub members: Vec<TeamMember>,
     pub name: String,
-    pub owner_user_id: UserId,
+    pub owner_user_id: Id<UserMarker>,
 }
 
 #[cfg(test)]
 mod tests {
-    use super::{Team, TeamId, UserId};
+    use super::Team;
+    use crate::{id::Id, test::image_hash};
     use serde::{Deserialize, Serialize};
     use serde_test::Token;
     use static_assertions::{assert_fields, assert_impl_all};
@@ -38,11 +45,11 @@ mod tests {
     #[test]
     fn test_team() {
         let value = Team {
-            icon: Some("hash".to_owned()),
-            id: TeamId::new(1).expect("non zero"),
+            icon: Some(image_hash::ICON),
+            id: Id::new(1),
             members: Vec::new(),
             name: "team name".into(),
-            owner_user_id: UserId::new(2).expect("non zero"),
+            owner_user_id: Id::new(2),
         };
 
         serde_test::assert_tokens(
@@ -54,9 +61,9 @@ mod tests {
                 },
                 Token::Str("icon"),
                 Token::Some,
-                Token::Str("hash"),
+                Token::Str(image_hash::ICON_INPUT),
                 Token::Str("id"),
-                Token::NewtypeStruct { name: "TeamId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("1"),
                 Token::Str("members"),
                 Token::Seq { len: Some(0) },
@@ -64,7 +71,7 @@ mod tests {
                 Token::Str("name"),
                 Token::Str("team name"),
                 Token::Str("owner_user_id"),
-                Token::NewtypeStruct { name: "UserId" },
+                Token::NewtypeStruct { name: "Id" },
                 Token::Str("2"),
                 Token::StructEnd,
             ],
